@@ -178,16 +178,23 @@ class FileResponseMixin:
             raise MalformedRangeHeader("Only support bytes range")
 
         ranges = [
-            (int(_[0]), int(_[1]) + 1 if _[1] else max_size)
-            for _ in re.findall(r"(\d+)-(\d*)", ranges_str)
+            (
+                int(_[0]) if _[0] else max_size - int(_[1]),
+                int(_[1]) + 1 if _[0] and _[1] and int(_[1]) < max_size else max_size,
+            )
+            for _ in re.findall(r"(\d*)-(\d*)", ranges_str)
+            if _ != ("", "")
         ]
 
+        if len(ranges) == 0:
+            raise MalformedRangeHeader("Range header: range must be requested")
+
+        if any(not (0 <= start < max_size) for start, _ in ranges):
+            raise RangeNotSatisfiable(max_size)
+
         if any(start > end for start, end in ranges):
             raise MalformedRangeHeader("Range header: start must be less than end")
 
-        if any(end > max_size for _, end in ranges):
-            raise RangeNotSatisfiable(max_size)
-
         if len(ranges) == 1:
             return ranges
 
