@@ -13,9 +13,16 @@ from typing import (
 )
 
 if sys.version_info[:2] < (3, 8):
-    from typing_extensions import Final, Literal, Protocol, TypedDict, final
+    from typing_extensions import (
+        Final,
+        Literal,
+        Protocol,
+        TypedDict,
+        final,
+        runtime_checkable,
+    )
 else:
-    from typing import Final, Literal, Protocol, TypedDict, final
+    from typing import Final, Literal, Protocol, TypedDict, final, runtime_checkable
 
 __all__ = [
     "Scope",
@@ -27,12 +34,13 @@ __all__ = [
     "Environ",
     "StartResponse",
     "WSGIApp",
-] + [
     # built-in types
     "TypedDict",
     "Literal",
     "Final",
     "final",
+    "Protocol",
+    "runtime_checkable",
 ]
 
 # ASGI
@@ -53,15 +61,13 @@ ExcInfo = Tuple[Type[BaseException], BaseException, Optional[TracebackType]]
 
 
 class StartResponse(Protocol):
-    __slots__ = ()
-
     def __call__(
         self,
         status: str,
         response_headers: List[Tuple[str, str]],
-        exc_info: ExcInfo = None,
+        exc_info: Optional[ExcInfo] = None,
     ) -> None:
-        raise NotImplementedError
+        ...  # pragma: no cover
 
 
 WSGIApp = Callable[[Environ, StartResponse], Iterable[bytes]]
